@@ -76,29 +76,36 @@ class DataPoint():
          
 class DenMune():
    
-    def __init__ (self, data, file_2d ='', k_nearest=1, verpose=True, show_noise=False, rgn_tsne=False, prop_step=0):     
+    def __init__ (self, data, file_2d =None, k_nearest=1, verpose=True, show_noise=False, rgn_tsne=False, prop_step=0, delimiter=','):     
          
         self.analyzer = {}
         self.analyzer['exec_time'] = {}
         self.analyzer['n_points'] = {}
         self.analyzer['n_points']["noise"] = {}
+        self.analyzer["n_points"]["noise"]["type-1"] = 0
+        self.analyzer["n_points"]["noise"]["type-2"] = 0
         self.analyzer['n_points']["weak"] = {}
         self.analyzer["n_points"]["weak"]["all"] = 0
+        self.analyzer["n_points"]["weak"]["succeeded to merge"] = 0
+        self.analyzer["n_points"]["weak"]["failed to merge"] = 0
         self.analyzer["n_points"]["size"] = data.shape[0]
         self.analyzer["n_points"]["dim"] = data.shape[1]
         self.analyzer["validity"] = {}
         self.analyzer["n_clusters"] = {}
         self.analyzer["n_clusters"]["actual"] = 0
         self.analyzer["n_clusters"]["detected"] = 0
-        
-        if data.shape[1] != 2:
+        self.delimiter = delimiter
+
+        if data.shape[1] != 2 and file_2d is None:
+            raise Exception("Sorry, this is N-D dataset, file-2d parameter should not be empty")
+        elif data.shape[1] != 2 and file_2d is not None:    
             if  not os.path.isfile(file_2d) or rgn_tsne == True:
                 start = time.time()
                 self.generate_tsne(data, file_2d, 2)
                 end = time.time()
                 self.analyzer["exec_time"]["t_SNE"] = end-start
                
-            data = genfromtxt(file_2d , delimiter='\t')
+            data = genfromtxt(file_2d , delimiter=self.delimiter)
 
         start_time = time.time()
         
@@ -678,7 +685,7 @@ class DenMune():
         for i in range(data_len):
             for n in range(d):
                 mystr += str(round(dim_two[i][n],6))
-                if (n  < d-1):mystr += '\t'
+                if (n  < d-1):mystr += self.delimiter
                 if (n  == d-1): mystr += '\n'
 
         text_file = open(file_2d, "w")
